@@ -5,7 +5,7 @@ require 5.006_000;
 use constant WIN32  => $^O eq 'MSWin32';
 use constant PERL58 => $] > 5.007_000;
 require Encode if PERL58;
-$SVN::Notify::VERSION = '2.84';
+$SVN::Notify::VERSION = '2.85';
 
 # Make sure any output (such as from _dbpnt()) triggers no Perl warnings.
 if (PERL58) {
@@ -1462,11 +1462,32 @@ sub output_headers {
     $self->_dbpnt( "Outputting headers") if $self->{verbose} > 2;
 
     # Q-Encoding (RFC 2047)
-    my ($subj, $from, $to) = PERL58 ? map {
-        Encode::encode( 'MIME-Q', $_ );
-    } $self->{subject}, $self->{from}, join ', ', @{ $self->{to} } : (
-        $self->{subject}, $self->{from}, join ', ', @{ $self->{to} }
-    );
+    my $subj = PERL58 && $self->{subject} =~ /(?:\P{ASCII}|=)/s
+        ? Encode::encode( 'MIME-Q', $self->{subject} )
+        : $self->{subject};
+
+    # Q-Encode the phrase part of recipient headers.
+    my $norm;
+    if (PERL58) {
+        require Email::Address;
+        $norm = sub {
+            return join ', ' => map {
+                my ($addr) = Email::Address->parse($_);
+                if ($addr) {
+                    if (my $phrase = $addr->phrase) {
+                        $addr->phrase(Encode::encode( 'MIME-Q', $phrase ));
+                    }
+                    $addr->format;
+                } else {
+                    $_;
+                }
+            } @_;
+        };
+    } else {
+        $norm = sub { join ', ' => @_ };
+    }
+    my $from = $norm->($self->{from});
+    my $to = $norm->(@{ $self->{to} });
 
     my @headers = (
         "MIME-Version: 1.0\n",
@@ -1478,7 +1499,8 @@ sub output_headers {
         "Subject: $subj\n"
     );
 
-    push @headers, "Reply-To: $self->{reply_to}\n" if $self->{reply_to};
+    push @headers, 'Reply-To: ' . $norm->($self->{reply_to}) . "\n"
+        if $self->{reply_to};
 
     if (my $heads = $self->{add_headers}) {
         while (my ($k, $v) = each %{ $heads }) {
@@ -2570,7 +2592,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2004-2011 David E. Wheeler. Some Rights Reserved.
+Copyright (c) 2004-2016 David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
